pub struct CachedProcess<T> { /* private fields */ }
Cached process to avoid looking up a global process multiple times.

Implementations

source

impl<T> CachedProcess<T>

source

pub fn new(name: &'static str) -> Self

Construct a new process cache with a registered process name.

source

pub fn set(&self, value: T)

Sets the process cache value.

source

pub fn reset(&self)

Resets the process cache, causing subsequent calls to lookup the process again.